currency

package
v0.0.0-...-5fc39c8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 22, 2025 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the currency type in the database.
	Label = "currency"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedBy holds the string denoting the created_by field in the database.
	FieldCreatedBy = "created_by"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedBy holds the string denoting the updated_by field in the database.
	FieldUpdatedBy = "updated_by"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldCode holds the string denoting the code field in the database.
	FieldCode = "code"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldSign holds the string denoting the sign field in the database.
	FieldSign = "sign"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// Table holds the table name of the currency in the database.
	Table = "currency"
)
const DefaultStatus typex.SimpleStatus = "active"

Variables

var (
	Hooks [1]ent.Hook
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// CodeValidator is a validator for the "code" field. It is called by the builders before save.
	CodeValidator func(string) error
	// NameValidator is a validator for the "name" field. It is called by the builders before save.
	NameValidator func(string) error
	// SignValidator is a validator for the "sign" field. It is called by the builders before save.
	SignValidator func(string) error
)

Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:

import _ "github.com/woocoos/knockout/ent/runtime"

Columns holds all SQL columns for currency fields.

Functions

func And

func And(predicates ...predicate.Currency) predicate.Currency

And groups predicates with the AND operator between them.

func Code

func Code(v string) predicate.Currency

Code applies equality check predicate on the "code" field. It's identical to CodeEQ.

func CodeContains

func CodeContains(v string) predicate.Currency

CodeContains applies the Contains predicate on the "code" field.

func CodeContainsFold

func CodeContainsFold(v string) predicate.Currency

CodeContainsFold applies the ContainsFold predicate on the "code" field.

func CodeEQ

func CodeEQ(v string) predicate.Currency

CodeEQ applies the EQ predicate on the "code" field.

func CodeEqualFold

func CodeEqualFold(v string) predicate.Currency

CodeEqualFold applies the EqualFold predicate on the "code" field.

func CodeGT

func CodeGT(v string) predicate.Currency

CodeGT applies the GT predicate on the "code" field.

func CodeGTE

func CodeGTE(v string) predicate.Currency

CodeGTE applies the GTE predicate on the "code" field.

func CodeHasPrefix

func CodeHasPrefix(v string) predicate.Currency

CodeHasPrefix applies the HasPrefix predicate on the "code" field.

func CodeHasSuffix

func CodeHasSuffix(v string) predicate.Currency

CodeHasSuffix applies the HasSuffix predicate on the "code" field.

func CodeIn

func CodeIn(vs ...string) predicate.Currency

CodeIn applies the In predicate on the "code" field.

func CodeLT

func CodeLT(v string) predicate.Currency

CodeLT applies the LT predicate on the "code" field.

func CodeLTE

func CodeLTE(v string) predicate.Currency

CodeLTE applies the LTE predicate on the "code" field.

func CodeNEQ

func CodeNEQ(v string) predicate.Currency

CodeNEQ applies the NEQ predicate on the "code" field.

func CodeNotIn

func CodeNotIn(vs ...string) predicate.Currency

CodeNotIn applies the NotIn predicate on the "code" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.Currency

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Currency

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Currency

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Currency

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Currency

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Currency

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Currency

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Currency

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Currency

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func CreatedBy

func CreatedBy(v int) predicate.Currency

CreatedBy applies equality check predicate on the "created_by" field. It's identical to CreatedByEQ.

func CreatedByEQ

func CreatedByEQ(v int) predicate.Currency

CreatedByEQ applies the EQ predicate on the "created_by" field.

func CreatedByGT

func CreatedByGT(v int) predicate.Currency

CreatedByGT applies the GT predicate on the "created_by" field.

func CreatedByGTE

func CreatedByGTE(v int) predicate.Currency

CreatedByGTE applies the GTE predicate on the "created_by" field.

func CreatedByIn

func CreatedByIn(vs ...int) predicate.Currency

CreatedByIn applies the In predicate on the "created_by" field.

func CreatedByLT

func CreatedByLT(v int) predicate.Currency

CreatedByLT applies the LT predicate on the "created_by" field.

func CreatedByLTE

func CreatedByLTE(v int) predicate.Currency

CreatedByLTE applies the LTE predicate on the "created_by" field.

func CreatedByNEQ

func CreatedByNEQ(v int) predicate.Currency

CreatedByNEQ applies the NEQ predicate on the "created_by" field.

func CreatedByNotIn

func CreatedByNotIn(vs ...int) predicate.Currency

CreatedByNotIn applies the NotIn predicate on the "created_by" field.

func ID

func ID(id int) predicate.Currency

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Currency

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Currency

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Currency

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Currency

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Currency

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Currency

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Currency

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Currency

IDNotIn applies the NotIn predicate on the ID field.

func Name

func Name(v string) predicate.Currency

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.Currency

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.Currency

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.Currency

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.Currency

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.Currency

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.Currency

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.Currency

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.Currency

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.Currency

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.Currency

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.Currency

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.Currency

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.Currency

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Currency) predicate.Currency

Or groups predicates with the OR operator between them.

func Sign

func Sign(v string) predicate.Currency

Sign applies equality check predicate on the "sign" field. It's identical to SignEQ.

func SignContains

func SignContains(v string) predicate.Currency

SignContains applies the Contains predicate on the "sign" field.

func SignContainsFold

func SignContainsFold(v string) predicate.Currency

SignContainsFold applies the ContainsFold predicate on the "sign" field.

func SignEQ

func SignEQ(v string) predicate.Currency

SignEQ applies the EQ predicate on the "sign" field.

func SignEqualFold

func SignEqualFold(v string) predicate.Currency

SignEqualFold applies the EqualFold predicate on the "sign" field.

func SignGT

func SignGT(v string) predicate.Currency

SignGT applies the GT predicate on the "sign" field.

func SignGTE

func SignGTE(v string) predicate.Currency

SignGTE applies the GTE predicate on the "sign" field.

func SignHasPrefix

func SignHasPrefix(v string) predicate.Currency

SignHasPrefix applies the HasPrefix predicate on the "sign" field.

func SignHasSuffix

func SignHasSuffix(v string) predicate.Currency

SignHasSuffix applies the HasSuffix predicate on the "sign" field.

func SignIn

func SignIn(vs ...string) predicate.Currency

SignIn applies the In predicate on the "sign" field.

func SignIsNil

func SignIsNil() predicate.Currency

SignIsNil applies the IsNil predicate on the "sign" field.

func SignLT

func SignLT(v string) predicate.Currency

SignLT applies the LT predicate on the "sign" field.

func SignLTE

func SignLTE(v string) predicate.Currency

SignLTE applies the LTE predicate on the "sign" field.

func SignNEQ

func SignNEQ(v string) predicate.Currency

SignNEQ applies the NEQ predicate on the "sign" field.

func SignNotIn

func SignNotIn(vs ...string) predicate.Currency

SignNotIn applies the NotIn predicate on the "sign" field.

func SignNotNil

func SignNotNil() predicate.Currency

SignNotNil applies the NotNil predicate on the "sign" field.

func StatusEQ

StatusEQ applies the EQ predicate on the "status" field.

func StatusIn

func StatusIn(vs ...typex.SimpleStatus) predicate.Currency

StatusIn applies the In predicate on the "status" field.

func StatusNEQ

func StatusNEQ(v typex.SimpleStatus) predicate.Currency

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

func StatusNotIn(vs ...typex.SimpleStatus) predicate.Currency

StatusNotIn applies the NotIn predicate on the "status" field.

func StatusValidator

func StatusValidator(s typex.SimpleStatus) error

StatusValidator is a validator for the "status" field enum values. It is called by the builders before save.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.Currency

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.Currency

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.Currency

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.Currency

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.Currency

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtIsNil

func UpdatedAtIsNil() predicate.Currency

UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.Currency

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.Currency

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.Currency

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.Currency

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func UpdatedAtNotNil

func UpdatedAtNotNil() predicate.Currency

UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.

func UpdatedBy

func UpdatedBy(v int) predicate.Currency

UpdatedBy applies equality check predicate on the "updated_by" field. It's identical to UpdatedByEQ.

func UpdatedByEQ

func UpdatedByEQ(v int) predicate.Currency

UpdatedByEQ applies the EQ predicate on the "updated_by" field.

func UpdatedByGT

func UpdatedByGT(v int) predicate.Currency

UpdatedByGT applies the GT predicate on the "updated_by" field.

func UpdatedByGTE

func UpdatedByGTE(v int) predicate.Currency

UpdatedByGTE applies the GTE predicate on the "updated_by" field.

func UpdatedByIn

func UpdatedByIn(vs ...int) predicate.Currency

UpdatedByIn applies the In predicate on the "updated_by" field.

func UpdatedByIsNil

func UpdatedByIsNil() predicate.Currency

UpdatedByIsNil applies the IsNil predicate on the "updated_by" field.

func UpdatedByLT

func UpdatedByLT(v int) predicate.Currency

UpdatedByLT applies the LT predicate on the "updated_by" field.

func UpdatedByLTE

func UpdatedByLTE(v int) predicate.Currency

UpdatedByLTE applies the LTE predicate on the "updated_by" field.

func UpdatedByNEQ

func UpdatedByNEQ(v int) predicate.Currency

UpdatedByNEQ applies the NEQ predicate on the "updated_by" field.

func UpdatedByNotIn

func UpdatedByNotIn(vs ...int) predicate.Currency

UpdatedByNotIn applies the NotIn predicate on the "updated_by" field.

func UpdatedByNotNil

func UpdatedByNotNil() predicate.Currency

UpdatedByNotNil applies the NotNil predicate on the "updated_by" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Currency queries.

func ByCode

func ByCode(opts ...sql.OrderTermOption) OrderOption

ByCode orders the results by the code field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByCreatedBy

func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption

ByCreatedBy orders the results by the created_by field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func BySign

func BySign(opts ...sql.OrderTermOption) OrderOption

BySign orders the results by the sign field.

func ByStatus

func ByStatus(opts ...sql.OrderTermOption) OrderOption

ByStatus orders the results by the status field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUpdatedBy

func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption

ByUpdatedBy orders the results by the updated_by field.

Jump to