Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Currency) predicate.Currency
- func Code(v string) predicate.Currency
- func CodeContains(v string) predicate.Currency
- func CodeContainsFold(v string) predicate.Currency
- func CodeEQ(v string) predicate.Currency
- func CodeEqualFold(v string) predicate.Currency
- func CodeGT(v string) predicate.Currency
- func CodeGTE(v string) predicate.Currency
- func CodeHasPrefix(v string) predicate.Currency
- func CodeHasSuffix(v string) predicate.Currency
- func CodeIn(vs ...string) predicate.Currency
- func CodeLT(v string) predicate.Currency
- func CodeLTE(v string) predicate.Currency
- func CodeNEQ(v string) predicate.Currency
- func CodeNotIn(vs ...string) predicate.Currency
- func CreatedAt(v time.Time) predicate.Currency
- func CreatedAtEQ(v time.Time) predicate.Currency
- func CreatedAtGT(v time.Time) predicate.Currency
- func CreatedAtGTE(v time.Time) predicate.Currency
- func CreatedAtIn(vs ...time.Time) predicate.Currency
- func CreatedAtLT(v time.Time) predicate.Currency
- func CreatedAtLTE(v time.Time) predicate.Currency
- func CreatedAtNEQ(v time.Time) predicate.Currency
- func CreatedAtNotIn(vs ...time.Time) predicate.Currency
- func CreatedBy(v int) predicate.Currency
- func CreatedByEQ(v int) predicate.Currency
- func CreatedByGT(v int) predicate.Currency
- func CreatedByGTE(v int) predicate.Currency
- func CreatedByIn(vs ...int) predicate.Currency
- func CreatedByLT(v int) predicate.Currency
- func CreatedByLTE(v int) predicate.Currency
- func CreatedByNEQ(v int) predicate.Currency
- func CreatedByNotIn(vs ...int) predicate.Currency
- func ID(id int) predicate.Currency
- func IDEQ(id int) predicate.Currency
- func IDGT(id int) predicate.Currency
- func IDGTE(id int) predicate.Currency
- func IDIn(ids ...int) predicate.Currency
- func IDLT(id int) predicate.Currency
- func IDLTE(id int) predicate.Currency
- func IDNEQ(id int) predicate.Currency
- func IDNotIn(ids ...int) predicate.Currency
- func Name(v string) predicate.Currency
- func NameContains(v string) predicate.Currency
- func NameContainsFold(v string) predicate.Currency
- func NameEQ(v string) predicate.Currency
- func NameEqualFold(v string) predicate.Currency
- func NameGT(v string) predicate.Currency
- func NameGTE(v string) predicate.Currency
- func NameHasPrefix(v string) predicate.Currency
- func NameHasSuffix(v string) predicate.Currency
- func NameIn(vs ...string) predicate.Currency
- func NameLT(v string) predicate.Currency
- func NameLTE(v string) predicate.Currency
- func NameNEQ(v string) predicate.Currency
- func NameNotIn(vs ...string) predicate.Currency
- func Not(p predicate.Currency) predicate.Currency
- func Or(predicates ...predicate.Currency) predicate.Currency
- func Sign(v string) predicate.Currency
- func SignContains(v string) predicate.Currency
- func SignContainsFold(v string) predicate.Currency
- func SignEQ(v string) predicate.Currency
- func SignEqualFold(v string) predicate.Currency
- func SignGT(v string) predicate.Currency
- func SignGTE(v string) predicate.Currency
- func SignHasPrefix(v string) predicate.Currency
- func SignHasSuffix(v string) predicate.Currency
- func SignIn(vs ...string) predicate.Currency
- func SignIsNil() predicate.Currency
- func SignLT(v string) predicate.Currency
- func SignLTE(v string) predicate.Currency
- func SignNEQ(v string) predicate.Currency
- func SignNotIn(vs ...string) predicate.Currency
- func SignNotNil() predicate.Currency
- func StatusEQ(v typex.SimpleStatus) predicate.Currency
- func StatusIn(vs ...typex.SimpleStatus) predicate.Currency
- func StatusNEQ(v typex.SimpleStatus) predicate.Currency
- func StatusNotIn(vs ...typex.SimpleStatus) predicate.Currency
- func StatusValidator(s typex.SimpleStatus) error
- func UpdatedAt(v time.Time) predicate.Currency
- func UpdatedAtEQ(v time.Time) predicate.Currency
- func UpdatedAtGT(v time.Time) predicate.Currency
- func UpdatedAtGTE(v time.Time) predicate.Currency
- func UpdatedAtIn(vs ...time.Time) predicate.Currency
- func UpdatedAtIsNil() predicate.Currency
- func UpdatedAtLT(v time.Time) predicate.Currency
- func UpdatedAtLTE(v time.Time) predicate.Currency
- func UpdatedAtNEQ(v time.Time) predicate.Currency
- func UpdatedAtNotIn(vs ...time.Time) predicate.Currency
- func UpdatedAtNotNil() predicate.Currency
- func UpdatedBy(v int) predicate.Currency
- func UpdatedByEQ(v int) predicate.Currency
- func UpdatedByGT(v int) predicate.Currency
- func UpdatedByGTE(v int) predicate.Currency
- func UpdatedByIn(vs ...int) predicate.Currency
- func UpdatedByIsNil() predicate.Currency
- func UpdatedByLT(v int) predicate.Currency
- func UpdatedByLTE(v int) predicate.Currency
- func UpdatedByNEQ(v int) predicate.Currency
- func UpdatedByNotIn(vs ...int) predicate.Currency
- func UpdatedByNotNil() predicate.Currency
- func ValidColumn(column string) bool
- type OrderOption
- func ByCode(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func BySign(opts ...sql.OrderTermOption) OrderOption
- func ByStatus(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the currency type in the database. Label = "currency" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedBy holds the string denoting the created_by field in the database. FieldCreatedBy = "created_by" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedBy holds the string denoting the updated_by field in the database. FieldUpdatedBy = "updated_by" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldCode holds the string denoting the code field in the database. FieldCode = "code" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldSign holds the string denoting the sign field in the database. FieldSign = "sign" // FieldStatus holds the string denoting the status field in the database. FieldStatus = "status" // Table holds the table name of the currency in the database. Table = "currency" )
const DefaultStatus typex.SimpleStatus = "active"
Variables ¶
var ( Hooks [1]ent.Hook // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // CodeValidator is a validator for the "code" field. It is called by the builders before save. CodeValidator func(string) error // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // SignValidator is a validator for the "sign" field. It is called by the builders before save. SignValidator func(string) error )
Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:
import _ "github.com/woocoos/knockout/ent/runtime"
var Columns = []string{ FieldID, FieldCreatedBy, FieldCreatedAt, FieldUpdatedBy, FieldUpdatedAt, FieldCode, FieldName, FieldSign, FieldStatus, }
Columns holds all SQL columns for currency fields.
Functions ¶
func CodeContains ¶
CodeContains applies the Contains predicate on the "code" field.
func CodeContainsFold ¶
CodeContainsFold applies the ContainsFold predicate on the "code" field.
func CodeEqualFold ¶
CodeEqualFold applies the EqualFold predicate on the "code" field.
func CodeHasPrefix ¶
CodeHasPrefix applies the HasPrefix predicate on the "code" field.
func CodeHasSuffix ¶
CodeHasSuffix applies the HasSuffix predicate on the "code" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func CreatedBy ¶
CreatedBy applies equality check predicate on the "created_by" field. It's identical to CreatedByEQ.
func CreatedByEQ ¶
CreatedByEQ applies the EQ predicate on the "created_by" field.
func CreatedByGT ¶
CreatedByGT applies the GT predicate on the "created_by" field.
func CreatedByGTE ¶
CreatedByGTE applies the GTE predicate on the "created_by" field.
func CreatedByIn ¶
CreatedByIn applies the In predicate on the "created_by" field.
func CreatedByLT ¶
CreatedByLT applies the LT predicate on the "created_by" field.
func CreatedByLTE ¶
CreatedByLTE applies the LTE predicate on the "created_by" field.
func CreatedByNEQ ¶
CreatedByNEQ applies the NEQ predicate on the "created_by" field.
func CreatedByNotIn ¶
CreatedByNotIn applies the NotIn predicate on the "created_by" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func SignContains ¶
SignContains applies the Contains predicate on the "sign" field.
func SignContainsFold ¶
SignContainsFold applies the ContainsFold predicate on the "sign" field.
func SignEqualFold ¶
SignEqualFold applies the EqualFold predicate on the "sign" field.
func SignHasPrefix ¶
SignHasPrefix applies the HasPrefix predicate on the "sign" field.
func SignHasSuffix ¶
SignHasSuffix applies the HasSuffix predicate on the "sign" field.
func SignNotNil ¶
SignNotNil applies the NotNil predicate on the "sign" field.
func StatusEQ ¶
func StatusEQ(v typex.SimpleStatus) predicate.Currency
StatusEQ applies the EQ predicate on the "status" field.
func StatusIn ¶
func StatusIn(vs ...typex.SimpleStatus) predicate.Currency
StatusIn applies the In predicate on the "status" field.
func StatusNEQ ¶
func StatusNEQ(v typex.SimpleStatus) predicate.Currency
StatusNEQ applies the NEQ predicate on the "status" field.
func StatusNotIn ¶
func StatusNotIn(vs ...typex.SimpleStatus) predicate.Currency
StatusNotIn applies the NotIn predicate on the "status" field.
func StatusValidator ¶
func StatusValidator(s typex.SimpleStatus) error
StatusValidator is a validator for the "status" field enum values. It is called by the builders before save.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtIsNil ¶
UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func UpdatedAtNotNil ¶
UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.
func UpdatedBy ¶
UpdatedBy applies equality check predicate on the "updated_by" field. It's identical to UpdatedByEQ.
func UpdatedByEQ ¶
UpdatedByEQ applies the EQ predicate on the "updated_by" field.
func UpdatedByGT ¶
UpdatedByGT applies the GT predicate on the "updated_by" field.
func UpdatedByGTE ¶
UpdatedByGTE applies the GTE predicate on the "updated_by" field.
func UpdatedByIn ¶
UpdatedByIn applies the In predicate on the "updated_by" field.
func UpdatedByIsNil ¶
UpdatedByIsNil applies the IsNil predicate on the "updated_by" field.
func UpdatedByLT ¶
UpdatedByLT applies the LT predicate on the "updated_by" field.
func UpdatedByLTE ¶
UpdatedByLTE applies the LTE predicate on the "updated_by" field.
func UpdatedByNEQ ¶
UpdatedByNEQ applies the NEQ predicate on the "updated_by" field.
func UpdatedByNotIn ¶
UpdatedByNotIn applies the NotIn predicate on the "updated_by" field.
func UpdatedByNotNil ¶
UpdatedByNotNil applies the NotNil predicate on the "updated_by" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Currency queries.
func ByCode ¶
func ByCode(opts ...sql.OrderTermOption) OrderOption
ByCode orders the results by the code field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByCreatedBy ¶
func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption
ByCreatedBy orders the results by the created_by field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func BySign ¶
func BySign(opts ...sql.OrderTermOption) OrderOption
BySign orders the results by the sign field.
func ByStatus ¶
func ByStatus(opts ...sql.OrderTermOption) OrderOption
ByStatus orders the results by the status field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUpdatedBy ¶
func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption
ByUpdatedBy orders the results by the updated_by field.